recalib(xc, yc, id = NULL, data, xcnew = NULL, ycnew = NULL, model, from, to)x data to be
recalibrated.y data to be
recalibrated.from and to rows. If NULL
then recalibrate all rows.xc, yc and id.xc. If default
NULL then use names xcnew1... .yc. If default
NULL then use names ycnew1... .sitar model defining the random effects to be used for
recalibration.id defining existing data (must be a single row
in coef{model}).id defining data to be recalibrated (a single row
in coef{model}).data with the from rows of
xc and yc recalibrated.
recalib recalibrates the values of xc and yc based on
model. xc values are changed to:(xc-c(coef[from,'b']))*exp(coef[from,'c']-coef[to,'c'])+coef[to,'b'].
yc values are changed to: yc-coef[from,'a']+coef[to,'a'].